Search.setIndex({envversion:42,terms:{code:0,help:0,just:0,text:0,base_opt:0,lack:0,directli:0,through:0,same:0,follow:0,alt:0,find:0,entiti:0,xml:0,web:0,onli:0,locat:0,execut:0,img:0,also:0,chosen:0,fix:0,littl:0,should:0,list:0,window:0,program:0,dict:0,under:0,various:0,tidylib:0,might:0,modul:0,cvsroot:0,meant:0,them:0,sourc:0,hit:0,around:0,thei:0,get:0,fals:0,computerhop:0,pypi:0,quickref:0,mainten:0,prebuild:0,veri:0,utf:0,discuss:0,pserver:0,release_tidy_doc:0,bar:0,like:0,anyth:0,separ:0,manual:0,server:0,"try":0,"default":0,"boolean":0,snippet:0,quick:0,output:0,unicod:0,complet:0,out:0,manag:0,system:0,set:0,replac:0,libtidi:0,linux:0,some:0,back:0,ensur:0,see:0,meta:0,result:0,pass:0,proper:0,librari:0,longstand:0,affili:0,what:0,unclos:0,insenst:0,open:0,someth:0,normal:0,abl:0,per:0,dll:0,current:0,written:0,version:0,ampersand:0,between:0,print:0,"import":0,net:0,content:0,boost:0,correct:0,can:0,full:0,run:0,behavior:0,slight:0,numer:0,gener:0,error:0,here:0,bodi:0,html4:[],extent:0,releas:0,path:0,modifi:0,sinc:0,valu:0,both:0,convert:0,indent:0,pretti:0,thread:0,etc:0,yum:0,outsid:0,you:0,mani:0,implement:0,com:0,produc:0,first:0,softwar:0,obviou:0,onc:0,transit:0,clariti:0,encod:0,number:0,apt:0,two:0,bsd:0,instruct:0,alreadi:0,messag:0,dylib:0,wrap:0,articl:0,miss:0,your:0,from:0,describ:0,support:0,overlook:0,question:0,add:0,been:0,mark:0,avail:0,strict:0,strip:0,much:0,call:0,includ:0,termin:0,defens:0,store:0,more:0,doctyp:0,unescap:0,src:0,forc:0,tool:0,about:0,tidy_frag:0,argument:0,warn:0,link:0,too:0,newer:0,sens:0,actual:0,line:0,"true":0,present:0,must:0,"case":0,none:0,word:0,consist:0,provid:0,checkout:0,outlin:0,sourceforg:0,troubl:0,charact:0,project:0,below:0,tag:0,thin:0,str:0,were:0,otherwis:0,anonym:0,similar:0,complain:0,expect:0,pre:0,gone:0,empti:0,fragment:0,certain:0,share:0,site:0,jpg:0,wrapper:0,packag:0,itself:0,keep_doc:0,unreli:0,have:0,pip:0,"return":0,download:0,work:0,string:0,incorrect:0,alwai:0,vista:0,end:0,perform:0,allow:0,make:0,especi:0,when:0,invalid:0,note:0,how:0,valid:0,decod:0,build:0,which:0,test:0,instead:[],xhtml:0,document:0,config:0,updat:0,http:0,distribut:0,index:0,previou:0,otild:0,capabl:0,briefli:0,larg:0,user:0,thi:0,mai:0,develop:0,"short":0,don:0,ani:0,directori:0,doc:0,markup:0,after:0,well:0,object:0,element:0,inform:0,without:0,command:0,place:0,clean:0,titl:0,tidy_docu:0,order:0,tidy_fraga:0,latest:0},objtypes:{"0":"py:function"},objnames:{"0":["py","function","Python function"]},filenames:["index"],titles:["PyTidyLib: A Python Interface to HTML Tidy"],objects:{tidylib:{tidy_document:[0,0,1,""],tidy_fragment:[0,0,1,""],release_tidy_doc:[0,0,1,""]}},titleterms:{"function":0,name:0,convent:0,pytidylib:0,python:0,configur:0,exampl:0,html:0,interfac:0,small:0,instal:0,refer:0,tidi:0,option:0}})