# Configuration file for Sphinx documentation tool

extensions = ['sphinx.ext.autodoc']

master_doc = "index"

project = "pytidylib"
copyright = "2009-2014 Jason Stitt"
version = "0.1"
language = "en"

html_title = "pytidylib module"

